package com.sooka.sponest.dataexchange.exchange.controller;


import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.exception.file.FileException;
import com.ruoyi.common.core.utils.file.FilePrefixUtils;
import com.ruoyi.system.api.RemoteConfigService;
import com.ruoyi.system.api.RemoteFileService;
import com.ruoyi.system.api.domain.SysFile;
import com.sooka.sponest.dataexchange.util.spring.SpringUtils;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.sooka.sponest.dataexchange.exchange.domian.DataExchangeEntity;
import com.sooka.sponest.dataexchange.exchange.domian.LoginBody;
import com.sooka.sponest.dataexchange.util.RestUtil;
import com.sooka.sponest.dataexchange.remoteapi.service.center.auth.RemoteAuthBaseService;
import com.sooka.sponest.dataexchange.remoteapi.service.center.event.RemoteEventBaseService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Controller;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Slf4j
@Controller
@RequestMapping("/data/exchange")
public class ExchangeController {

    @Resource
    private RemoteAuthBaseService remoteAuthBaseService;
    @Resource
    private RemoteEventBaseService remoteEventBaseService;
    @Resource
    private RemoteConfigService remoteConfigService;

    //    @Value("${}")
    private String url;

    /**
     * 获取秘钥接口
     */
    @PostMapping("/getRemoteSecretKey")
    @ResponseBody
    public R<?> getRemoteSecretKey() {
        R<?> result = remoteAuthBaseService.getRemoteSecretKey();
        log.info("result:{}",result.getData());
        if (result.getCode() == 200) {
            return R.ok(result.getData().toString(), "获取成功");
        } else {
            return R.fail("获取失败");
        }
    }

    /**
     * 获取token
     */
    @PostMapping("/getToken")
    @ResponseBody
    public R<?> getToken(@RequestBody LoginBody form) {
        R<?> result = remoteAuthBaseService.loginRemote(form);
        log.info("result:{}",result.getData());
        if (result.getCode() == 200) {
            Map<String, Object> json = (Map<String, Object>) result.getData();
            return R.ok(json.get("access_token").toString(), "获取成功");
        } else {
            return R.fail("获取失败");
        }
    }

    @PostMapping("/straightPushData")
    @ResponseBody
    public R<?> straightPushData(@RequestBody DataExchangeEntity dataExchangeEntity) {
        log.info("dataExchangeEntity:{}", dataExchangeEntity);
        List<String> pictureList = new ArrayList<>();
        if (StringUtils.isNotEmpty(SecurityUtils.getToken()) && !CollectionUtils.isEmpty(dataExchangeEntity.getEventPicture())) {
            log.info("token:{}", StringUtils.isNotEmpty(SecurityUtils.getToken()));
            for (String picture : dataExchangeEntity.getEventPicture()) {
                if (!"image".equals(FilePrefixUtils.getUrlSuffix(picture))) {
                    log.error("事件图片必须为图片格式---{}", dataExchangeEntity);
                    return R.fail("事件图片必须为图片格式");
                } else {
                    MultipartFile multipartFile = FilePrefixUtils.urlToMultipartFile(picture, System.currentTimeMillis() + ".jpg");
                    log.info("multipartFile:{}", multipartFile);
                    try {
                        SysFile sysFile = SpringUtils.getBean(RemoteFileService.class).upload(multipartFile).getData();
                        log.info("sysFile:{}", sysFile);
                        pictureList.add(sysFile.getUrl());
                    } catch (FileException e) {
                        log.info("上传附件失败");
                    }

                }
            }
            dataExchangeEntity.setPictureUrlList(pictureList);
            R<?> result = remoteEventBaseService.insert3rdSystemEvent(dataExchangeEntity);
            log.info("insert3rdSystemEvent:{}", result);
            if (result.getCode() == 200) {
                return R.ok(null, "推送成功");
            } else {
                return R.fail(result.getMsg());
            }
        } else {
            return R.fail("推送失败");
        }
    }


    @PostMapping("/receiveEventData")
    @ResponseBody
    public R<?> receiveEventData(@RequestBody DataExchangeEntity dataExchangeEntity) {
        System.out.println(dataExchangeEntity);
        R<String> appUrl = remoteConfigService.remotegetConfigKey("appUrl");
        List<String> pictureList = new ArrayList<>();
        for (String picture : dataExchangeEntity.getEventPicture()) {
            pictureList.add(appUrl.getData().toString() + picture);
        }
        dataExchangeEntity.setEventPicture(pictureList);
        // TODO: 2024/1/9 0009 待修改
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("", dataExchangeEntity);
        try {
            JSONObject result = RestUtil.post(url, jsonObject);
            log.info("远程调用119:{}", result);
        } catch (Exception e) {
            log.info("远程调用119报错");
        }
        return R.ok(null, "接收成功");
    }

}
